@@ -1,12 +1,10 @@
 from .base import BaseEstimator
 from .exception import NotFittedError
 from .mixins import PredictorMixin, TransformerMixin
-from .utils import trainer_uses_batch_training
 
 __all__ = [
     "BaseEstimator",
     "NotFittedError",
     "PredictorMixin",
     "TransformerMixin",
-    "trainer_uses_batch_training",
 ]
